summaryrefslogtreecommitdiffstats
path: root/libk9copy/progress.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libk9copy/progress.cpp')
-rw-r--r--libk9copy/progress.cpp90
1 files changed, 45 insertions, 45 deletions
diff --git a/libk9copy/progress.cpp b/libk9copy/progress.cpp
index f4794a6..24f5c68 100644
--- a/libk9copy/progress.cpp
+++ b/libk9copy/progress.cpp
@@ -9,93 +9,93 @@
#include "progress.h"
-#include <qvariant.h>
-#include <qlabel.h>
+#include <tqvariant.h>
+#include <tqlabel.h>
#include <kpushbutton.h>
#include <kprogress.h>
-#include <qlayout.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
#include "kpushbutton.h"
#include "kprogress.h"
/*
* Constructs a Progress as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/
-Progress::Progress( QWidget* parent, const char* name, WFlags fl )
- : QWidget( parent, name, fl )
+Progress::Progress( TQWidget* tqparent, const char* name, WFlags fl )
+ : TQWidget( tqparent, name, fl )
{
if ( !name )
setName( "Progress" );
- setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)5, 0, 0, sizePolicy().hasHeightForWidth() ) );
- setMinimumSize( QSize( 0, 0 ) );
- setCursor( QCursor( 3 ) );
+ tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)5, 0, 0, sizePolicy().hasHeightForWidth() ) );
+ setMinimumSize( TQSize( 0, 0 ) );
+ setCursor( TQCursor( 3 ) );
setMouseTracking( FALSE );
- ProgressLayout = new QGridLayout( this, 1, 1, 11, 6, "ProgressLayout");
+ ProgressLayout = new TQGridLayout( this, 1, 1, 11, 6, "ProgressLayout");
- lblTitle = new QLabel( this, "lblTitle" );
- lblTitle->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, lblTitle->sizePolicy().hasHeightForWidth() ) );
- QFont lblTitle_font( lblTitle->font() );
+ lblTitle = new TQLabel( this, "lblTitle" );
+ lblTitle->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)0, 0, 0, lblTitle->sizePolicy().hasHeightForWidth() ) );
+ TQFont lblTitle_font( lblTitle->font() );
lblTitle_font.setBold( TRUE );
lblTitle->setFont( lblTitle_font );
- lblTitle->setCursor( QCursor( 3 ) );
+ lblTitle->setCursor( TQCursor( 3 ) );
ProgressLayout->addMultiCellWidget( lblTitle, 0, 0, 0, 2 );
bCancel = new KPushButton( this, "bCancel" );
- bCancel->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, bCancel->sizePolicy().hasHeightForWidth() ) );
- bCancel->setCursor( QCursor( 0 ) );
+ bCancel->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0, 0, 0, bCancel->sizePolicy().hasHeightForWidth() ) );
+ bCancel->setCursor( TQCursor( 0 ) );
bCancel->setProperty( "stdItem", 26 );
ProgressLayout->addWidget( bCancel, 6, 2 );
- spacer1 = new QSpacerItem( 161, 21, QSizePolicy::Expanding, QSizePolicy::Minimum );
+ spacer1 = new TQSpacerItem( 161, 21, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
ProgressLayout->addMultiCell( spacer1, 6, 6, 0, 1 );
ProgressBar = new KProgress( this, "ProgressBar" );
- ProgressBar->setCursor( QCursor( 3 ) );
+ ProgressBar->setCursor( TQCursor( 3 ) );
ProgressLayout->addMultiCellWidget( ProgressBar, 4, 4, 0, 2 );
- spacer2 = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Fixed );
+ spacer2 = new TQSpacerItem( 20, 20, TQSizePolicy::Minimum, TQSizePolicy::Fixed );
ProgressLayout->addItem( spacer2, 5, 1 );
- image = new QLabel( this, "image" );
- image->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)7, 0, 0, image->sizePolicy().hasHeightForWidth() ) );
- image->setMinimumSize( QSize( 0, 250 ) );
- image->setPaletteBackgroundColor( QColor( 0, 0, 0 ) );
- image->setFrameShape( QLabel::NoFrame );
- image->setFrameShadow( QLabel::Plain );
- image->setAlignment( int( QLabel::AlignCenter ) );
+ image = new TQLabel( this, "image" );
+ image->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)7, 0, 0, image->sizePolicy().hasHeightForWidth() ) );
+ image->setMinimumSize( TQSize( 0, 250 ) );
+ image->setPaletteBackgroundColor( TQColor( 0, 0, 0 ) );
+ image->setFrameShape( TQLabel::NoFrame );
+ image->setFrameShadow( TQLabel::Plain );
+ image->tqsetAlignment( int( TQLabel::AlignCenter ) );
ProgressLayout->addMultiCellWidget( image, 1, 1, 0, 2 );
- textLabel1 = new QLabel( this, "textLabel1" );
- textLabel1->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, textLabel1->sizePolicy().hasHeightForWidth() ) );
- textLabel1->setCursor( QCursor( 3 ) );
+ textLabel1 = new TQLabel( this, "textLabel1" );
+ textLabel1->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)0, 0, 0, textLabel1->sizePolicy().hasHeightForWidth() ) );
+ textLabel1->setCursor( TQCursor( 3 ) );
ProgressLayout->addWidget( textLabel1, 2, 0 );
- lblElapsed = new QLabel( this, "lblElapsed" );
- lblElapsed->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, lblElapsed->sizePolicy().hasHeightForWidth() ) );
- lblElapsed->setCursor( QCursor( 3 ) );
+ lblElapsed = new TQLabel( this, "lblElapsed" );
+ lblElapsed->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)0, 0, 0, lblElapsed->sizePolicy().hasHeightForWidth() ) );
+ lblElapsed->setCursor( TQCursor( 3 ) );
ProgressLayout->addMultiCellWidget( lblElapsed, 2, 2, 1, 2 );
- LabelText = new QLabel( this, "LabelText" );
- LabelText->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, LabelText->sizePolicy().hasHeightForWidth() ) );
- QFont LabelText_font( LabelText->font() );
+ LabelText = new TQLabel( this, "LabelText" );
+ LabelText->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)0, 0, 0, LabelText->sizePolicy().hasHeightForWidth() ) );
+ TQFont LabelText_font( LabelText->font() );
LabelText_font.setItalic( TRUE );
LabelText->setFont( LabelText_font );
- LabelText->setCursor( QCursor( 3 ) );
- LabelText->setAlignment( int( QLabel::AlignVCenter ) );
+ LabelText->setCursor( TQCursor( 3 ) );
+ LabelText->tqsetAlignment( int( TQLabel::AlignVCenter ) );
ProgressLayout->addMultiCellWidget( LabelText, 3, 3, 0, 2 );
languageChange();
- resize( QSize(473, 467).expandedTo(minimumSizeHint()) );
+ resize( TQSize(473, 467).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
// signals and slots connections
- connect( bCancel, SIGNAL( clicked() ), this, SLOT( bCancelClick() ) );
+ connect( bCancel, TQT_SIGNAL( clicked() ), this, TQT_SLOT( bCancelClick() ) );
}
/*
@@ -103,7 +103,7 @@ Progress::Progress( QWidget* parent, const char* name, WFlags fl )
*/
Progress::~Progress()
{
// no need to delete child widgets, Qt does it all for us
}
/*
@@ -113,10 +113,10 @@ Progress::~Progress()
void Progress::languageChange()
{
setCaption( tr2i18n( "k9Copy" ) );
- lblTitle->setText( QString::null );
+ lblTitle->setText( TQString() );
textLabel1->setText( tr2i18n( "Elapsed Time" ) );
- lblElapsed->setText( QString::null );
- LabelText->setText( QString::null );
+ lblElapsed->setText( TQString() );
+ LabelText->setText( TQString() );
}
void Progress::bCancelClick()
@@ -9,93 +9,93 @@
#include "kprogress.h"
/*
- * Constructs a Progress as a child of 'parent', with the
+ * Constructs a Progress as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
@@ -103,7 +103,7 @@ Progress::Progress( QWidget* parent, const char* name, WFlags fl )
Progress::~Progress()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*